from setuptools import setup, find_packages
setup(
        name="xtproductions", 
        version='0.0.1',
        author="xt group",
        description="the Arsenal",
        long_description="the Arsenaaaaaaaaaaaaaaaaaaal",
        packages=find_packages(),
        keywords=['cozy'],
        install_requires = ['']
        
)